@@ -24,7 +24,7 @@ class upconfig(object):
         """
         self.updatePath = os.path.join(path if path else proDir, f"{file_name}.ini")
         self.config = configparser.RawConfigParser()
-        # self.config.read(self.updatePath, encoding="utf-8-sig")
+        self.config.read(self.updatePath, encoding="utf-8-sig")
         self.update_tag = update_tag
 
     def get_information(self, name):
@@ -48,8 +48,6 @@ class upconfig(object):
         :return:
         """
         try:
-            with open(self.updatePath, encoding="utf-8-sig") as f:
-                self.config.read_file(f)
             self.config.set(self.update_tag, f'{name}', date)
         except configparser.NoSectionError:
             with open(self.updatePath, 'a') as f:
@@ -72,8 +70,6 @@ class upconfig(object):
             value = self.config.get(self.update_tag, f'{name}')
         except:
             try:
-                with open(self.updatePath, encoding="utf-8-sig") as f:
-                    self.config.read_file(f)
                 self.config.set(self.update_tag, f'{name}', getdate(1))  # 如果报错说明没有这个则需要创建一个，并赋值为前一日
             except configparser.NoSectionError:
                 with open(self.updatePath, 'a') as f:
